@@ -21,7 +21,8 @@ import random
 import sys
 import traceback
 
-import gtk, gobject
+import gtk
+import gobject
 
 from solfege import gu
 from solfege import inputwidgets
@@ -543,6 +544,8 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         """
         self.handle_config_box_visibility()
         self.handle_statistics_page_sensibility()
+        if getattr(self, 'g_flashbar'):
+            self.g_flashbar.require_size(["|Xy"])
     def on_end_practise(self):
         pass
     def handle_config_box_visibility(self):
@@ -559,10 +562,10 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         try:
             if self.m_t.m_custom_mode:
                 self.g_statview.set_sensitive(False)
-                self.g_statview.set_tooltip_text(_("Statistics is disabled. Either because you selected a “Configure yourself” exercise, or because “Expert mode” is selected in the preferences window."))
+                self.g_statview.set_tooltip_text(_(u"Statistics is disabled. Either because you selected a “Configure yourself” exercise, or because “Expert mode” is selected in the preferences window."))
             else:
                 self.g_statview.set_sensitive(True)
-                self.g_statview.set_tooltip_text(None)
+                self.g_statview.set_tooltip_text("")
         except AttributeError: # not all exercises has g_statview
             pass
     def on_key_press_event(self, widget, event):
