@@ -23,6 +23,7 @@ import locale
 import logging
 import os
 import shutil
+import sqlite3
 import subprocess
 import sys
 import tempfile
@@ -202,14 +203,21 @@ class SolfegeApp(cfg.ConfigUtils):
                     clientid, portid = self.get_list("sound/alsa-client-port")
                 except ValueError:
                     clientid, portid = (None, None)
-                soundcard.initialise_alsa_sequencer((clientid, portid),
+                try:
+                    soundcard.initialise_alsa_sequencer((clientid, portid),
                             self.m_options.verbose_sound_init)
+                except alsaseq.SequencerError, e:
+                    logging.debug("initialise_alsa_sequencer failed. Using fake synth.")
+                    self.display_sound_init_error_message(e)
+                    soundcard.initialise_using_fake_synth(True)
+                    return
             else:
                 if solfege.splash_win:
                     solfege.splash_win.hide()
                 gu.dialog_ok(_("The pyalsa python module is missing"),
                     solfege.win,
                     _("Solfege was configured to the Python modules from www.alsa-project.org, but the modules was not found. You must reconfigure sound in the preferences window (Ctrl-F12) or restart Solfege in a way that it finds the module."))
+                soundcard.initialise_using_fake_synth(True)
                 if solfege.splash_win:
                     solfege.splash_win.show()
         elif cfg.get_string("sound/type") == "winsynth":
@@ -234,7 +242,6 @@ class SolfegeApp(cfg.ConfigUtils):
                 cfg.set_int("sound/synth_number", soundcard.synth.m_devnum)
         elif cfg.get_string("sound/type") == "external-midiplayer":
             soundcard.initialise_external_midiplayer(
-                    cfg.get_string("sound/midi_player"),
                     verbose_init=self.m_options.verbose_sound_init)
             soundcard.synth.error_report_cb = solfege.win.display_error_message
         elif cfg.get_string("sound/type") == '':
@@ -272,13 +279,13 @@ class SolfegeApp(cfg.ConfigUtils):
             """%s""" % str(e).decode(locale.getpreferredencoding(), 'replace'))
         elif isinstance(e, ImportError):
             solfege.win.display_error_message2(str(e), _("You should configure sound from the preferences window, and try to use an external midi player. Or try to recompile the program and check for error messages to see why the module is not built."))
-        elif e.errno == errno.EACCES:
+        elif getattr(e, 'errno', None) == errno.EACCES:
             solfege.win.display_error_message(
                 "The sound init failed: %s\n"
                 "The errno EACCES indicates that you don't have write "
                 "permission to the device."
                 % str(e).decode(locale.getpreferredencoding(), 'replace'))
-        elif e.errno == errno.EBUSY:
+        elif getattr(e, 'errno', None) == errno.EBUSY:
             solfege.win.display_error_message(
                 "The sound init failed: %s\n"
                 "It seems like some other program is using the device. You "
@@ -394,8 +401,14 @@ class SolfegeApp(cfg.ConfigUtils):
             # exceptions.
             if g.m_t.m_P and getattr(g.m_t.m_P, 'header', None):
                 g.on_end_practise()
-        solfege.db.conn.commit()
-        solfege.db.conn.close()
+        try:
+            solfege.db.conn.commit()
+        except sqlite3.ProgrammingError, e:
+            gu.display_exception_message(e)
+        try:
+            solfege.db.conn.close()
+        except sqlite3.ProgrammingError, e:
+            gu.display_exception_message(e)
         if soundcard.synth:
             soundcard.synth.close()
         shutil.rmtree(lessonfile.MusicBaseClass.temp_dir, True)
