@@ -43,6 +43,7 @@ class Teacher(abstract.Teacher):
         self.m_P.enter_test_mode()
     def exit_test_mode(self):
         self.m_statistics.exit_test_mode()
+        self.m_custom_mode = self.get_bool('gui/expert_mode')
     def give_up(self):
         self.q_status = self.QSTATUS_GIVE_UP
     def new_question(self):
@@ -139,6 +140,7 @@ class Gui(abstract.LessonbasedGui):
         self.setup_statisticsviewer(statisticsviewer.StatisticsViewer,
                                    _("Identify by name"))
         def _f(varname):
+            self.m_t.q_status = self.QSTATUS_NO
             self.setup_action_area_buttons()
         self.add_watch('ask_for_names', _f)
     def update_answer_buttons(self):
@@ -182,7 +184,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.hide()
     def give_up(self, _o=None):
         if self.m_t.q_status == self.QSTATUS_WRONG:
-            self.g_flashbar.push(_("The answer is: %s") % self.m_t.m_P.get_name())
+            self.g_flashbar.push(_("The answer is: {answer}"), answer=self.m_t.m_P.get_name())
             self.m_t.give_up()
             self.std_buttons_give_up()
             if self.m_t.m_P.header.have_music_displayer:
@@ -295,7 +297,7 @@ class Gui(abstract.LessonbasedGui):
             _("Wrong, but you have already solved this question"),
             _("You have to select some questions to practise."),
         ])
-        if not self.m_t.m_custom_mode:
+        if (not self.m_t.m_custom_mode) or solfege.app.m_test_mode:
             self.m_t.m_statistics.reset_session()
         self.g_statview.g_heading.set_text(self.m_t.m_P.header.title)
         self.g_music_displayer.clear(self.m_t.m_P.header.music_displayer_stafflines)
@@ -329,5 +331,4 @@ class Gui(abstract.LessonbasedGui):
         self.m_t.exit_test_mode()
         self.g_new.set_label(_("_New"))
         self.g_new.show()
-        self.on_start_practise()
         self.g_repeat_slowly.show()
